/*
    This sample illustrates how to configure the camera from a pylon feature stream file (.pfs)
    generated with the blaze Viewer.
*/

#include <ConsumerImplHelper/BlazeCamera.h>
#include <string>
#include <iostream>
#include <fstream>
#include <iomanip>

using namespace GenTLConsumerImplHelper;


void printUsage( char* argv[] )
{
    std::cerr << "Usage: " << argv[0] << " <pfs file>" << std::endl;
    std::cerr << "Example:" << argv[0] << " parameters.pfs" << std::endl;
}

int main(int argc, char* argv[])
{
    CBlazeCamera camera;

    int exitCode = EXIT_FAILURE;
    if ( argc != 2 )
    {
        printUsage( argv );
        goto exit;
    }

    try
    {
        CBlazeCamera::InitProducer();
        camera.OpenFirstCamera();
        camera.ParametrizeFromFile( argv[1] );
        
        // Work with camera...

        camera.Close();
    }
    catch ( GenICam::GenericException& e )
    {
        std::cerr << "Exception occurred: " << std::endl << e.GetDescription() << std::endl;
        // After successfully opening the camera, the IsConnected method can be used 
        // to check if the device is still connected.
        if ( camera.IsOpen() && ! camera.IsConnected() )
        {
            std::cerr << "Camera has been removed." << std::endl;
        }
    }

    // Release the GenTL producer and all of its resources. 
    // Note: Don't call TerminateProducer() until the destructor of the CBlazeCamera
    // class has been called. The destructor may require resources which may not
    // be available anymore after TerminateProducer() has been called.
    if ( CBlazeCamera::IsProducerInitialized() )
        CBlazeCamera::TerminateProducer();  // Won't throw any exceptions
    exitCode = EXIT_SUCCESS;

exit:
    std::cout << std::endl << "Press Enter to exit." << std::endl;
    while (std::cin.get() != '\n');

    return exitCode;
}
